@@ -3,14 +3,15 @@ Main interface for codestar-notifications service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codestar_notifications import (
+    from mypy_boto3_codestar_notifications import (
         Client,
         CodeStarNotificationsClient,
         ListEventTypesPaginator,
         ListNotificationRulesPaginator,
         ListTargetsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,10 +21,11 @@ Usage::
     list_event_types_paginator: ListEventTypesPaginator = client.get_paginator("list_event_types")
     list_notification_rules_paginator: ListNotificationRulesPaginator = client.get_paginator("list_notification_rules")
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
+    ```
 """
 from mypy_boto3_codestar_notifications.client import (
-    CodeStarNotificationsClient as Client,
     CodeStarNotificationsClient,
+    CodeStarNotificationsClient as Client,
 )
 from mypy_boto3_codestar_notifications.paginator import (
     ListEventTypesPaginator,
