@@ -3,8 +3,11 @@ Main interface for codestar-notifications service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codestar_notifications import (
+
+    from mypy_boto3_codestar_notifications import CodeStarNotificationsClient
+    from mypy_boto3_codestar_notifications import (
         ListEventTypesPaginator,
         ListNotificationRulesPaginator,
         ListTargetsPaginator,
@@ -15,6 +18,7 @@ Usage::
     list_event_types_paginator: ListEventTypesPaginator = client.get_paginator("list_event_types")
     list_notification_rules_paginator: ListNotificationRulesPaginator = client.get_paginator("list_notification_rules")
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
@@ -35,7 +39,7 @@ __all__ = ("ListEventTypesPaginator", "ListNotificationRulesPaginator", "ListTar
 
 class ListEventTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+    [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
     """
 
     def paginate(
@@ -44,13 +48,13 @@ class ListEventTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEventTypesResultTypeDef]:
         """
-        [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
+        [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
         """
 
 
 class ListNotificationRulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+    [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
     """
 
     def paginate(
@@ -59,13 +63,13 @@ class ListNotificationRulesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListNotificationRulesResultTypeDef]:
         """
-        [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
+        [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
         """
 
 
 class ListTargetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+    [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
     """
 
     def paginate(
@@ -74,5 +78,5 @@ class ListTargetsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTargetsResultTypeDef]:
         """
-        [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
+        [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
         """
