@@ -3,9 +3,11 @@ Main interface for codestar-notifications service type definitions.
 
 Usage::
 
-    from mypy_boto3.codestar_notifications.type_defs import EventTypeSummaryTypeDef
+    ```python
+    from mypy_boto3_codestar_notifications.type_defs import EventTypeSummaryTypeDef
 
     data: EventTypeSummaryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
